@@ -183,6 +183,7 @@ tm_league_team_urls <- function(country_name, start_year, league_url = NA) {
 #' @importFrom rlang .data
 #'
 #' @export
+#'
 tm_team_player_urls <- function(team_url) {
 
   main_url <- "https://www.transfermarkt.com"
@@ -190,8 +191,7 @@ tm_team_player_urls <- function(team_url) {
   tryCatch({team_page <- xml2::read_html(team_url)}, error = function(e) {team_page <- c()})
 
   player_urls <- team_page %>%
-    rvest::html_nodes("#yw1") %>% rvest::html_nodes(".hauptlink") %>%
-    rvest::html_nodes("a") %>% rvest::html_attr("href") %>%
+    rvest::html_nodes(".nowrap a") %>% rvest::html_attr("href") %>%
     unique() %>%
     paste0(main_url, .)
 
